<?php

namespace SRVX\Utils;


class LocalFile
{
	//用户上传的文件
	private $userPostFile = [];
	//存放用户上传文件的路径
	private $saveFilePath;
	//文件上传的最大尺寸
	private $maxFileSize;
	//默认允许用户上传的文件类型
	private $allow_type = ['gif', 'jpg', 'png', 'jpeg', 'ico', 'apk', 'mp4', "webp", "csv"];
	//上传文件最终保存的文件名
	private $finalFilePath;

	//删除文件
	public function delFile($file, $path)
	{
		if (file_exists($path)) {
			unlink($path . "/" . $file);
			return ["status" => true, "msg" => "删除成功"];
		}
		return ["status" => false, "msg" => "删除失败"];
	}

	//上传文件
	public function uploadFile($file, $path, $set_name = '', $size = 2000000000)
	{
		$this->maxFileSize  = $size;
		$this->userPostFile = $file;
		$this->saveFilePath = $path;
		//判断错误信息
		$errorMsg           = ["上传失败", "上传的文件超过了php.ini中设置的上限大小", "上传文件的大小超过了 HTML 表单中 MAX_FILE_SIZE 选项指定的值", "文件只有部分被上传", "没有文件被上传", "找不到临时文件夹", "文件写入失败"];
		if ($this->userPostFile['error'] != 0) {
			$msg = $errorMsg[$this->userPostFile['error']];
			empty($errorMsg[$this->userPostFile['error']]) && $msg = '上传失败';
			return ["status" => false, "msg" => $$msg];
		}
		//取当前文件名、临时文件名、大小、扩展名、后面将用到
		$tmpName = $this->userPostFile['tmp_name'];
		$size    = $this->userPostFile['size'];
		//获取扩展名
		$stuff = pathinfo($this->userPostFile['name']);
		$type  = $stuff['extension'];
		//检测当前上传文件是否非法提交
		if (!is_uploaded_file($tmpName)) {
			return ["status" => false, "msg" => "非法上传文件"];
		}
		//判断文件是否合法
		$extension = strtolower($type);
		if (!in_array($extension, $this->allow_type)) {
			return ["status" => false, "msg" => '上传文件不合法：' . $type];
		}
		if ($size > $this->maxFileSize) {
			return ["status" => false, "msg" => "上传文件不得超过限定大小"];
		}
		//重新给上传的文件命名
		$basename = time();
		!empty($set_name) && $basename = $set_name;
		$newName = $basename . '.' . $type;//移动后的文件名
//        if(!file_exists($this->saveFilePath)){
//            mkdir($this->saveFilePath, 0777,true);
//        }
		//组合新文件名在存到指定目录下
		$this->finalFilePath = $this->saveFilePath . "/" . $newName;
		//移动文件
		if (!move_uploaded_file($tmpName, $this->finalFilePath)) {
			return ["status" => false, "msg" => "上传失败"];
		}
		return ["status" => true, "msg" => "上传成功", "data" => $this->finalFilePath, "newFileName" => $newName];


	}


}