<?php
namespace SRVX\Utils;

use Phalcon\Di\Injectable;

/**
 * Class Sredis
 * @property \Redis $redis
 * @package SRVX\Utils
 */
class Sredis extends Injectable 
{

    protected $serialize = ['serialize', 'unserialize', 'phalcon_serialize:', 18];

    public function getCacheKey($name)
    {
        return $this->request->getHttpHost() . ':' . $name;
    }

    public function redisSet($name = '', $value = '', $expire = null)
    {   
        if ($this->redisHas($name)) {
            $first = false;
        }

        $key   = $this->getCacheKey($name);
        $value = $this->serialize($value);


        if ($expire) {
            $result = $this->redis->setex($key, $expire, $value);
        } else {
            $result = $this->redis->set($key, $value);
        }

        return isset($first) ? $first : $result;
    }


    public function redisGet($name, $default = false)
    {
        $value = $this->redis->get($this->getCacheKey($name));

        if (is_null($value) || false === $value) {
            return $default;
        }

        return $this->unserialize($value);
    }


    public function redisHas($name)
    {
        return $this->redis->exists($this->getCacheKey($name));
    }

    public function redisDel($name)
    {
        return $this->redis->del($this->getCacheKey($name));
    }

    public function del($data)
    {
        return $this->redis->del($data);
    }

    public function rpush($name, $value)
    {
        return $this->redis->rpush($this->getCacheKey($name), $value);
    }

    public function lpop($key)
    {
        return $this->redis->lpop($this->getCacheKey($key));
    }

    public function lock($name, $intExpireTime = '60')
    {
        return $this->redisSet($name, $name, $intExpireTime);
    }

    public function unlock($name)
    {
        return $this->redisDel($name);
    }
    
    protected function serialize($data)
    {
        if (is_scalar($data)) {
            return $data;
        }

        $serialize = $this->serialize[0];

        return $this->serialize[2] . $serialize($data);
    }

    protected function unserialize($data)
    {
        if (0 === strpos($data, $this->serialize[2])) {
            $unserialize = $this->serialize[1];
            return $unserialize(substr($data, $this->serialize[3]));
        } else {
            return $data;
        }
    }

    public function keys($data)
    {
        return $this->redis->keys($data);
    }
}